@@ -48,7 +48,7 @@
 #' @param kappa Numeric positive constant. Metropolis-Hastings proposal
 #' variation coefficient for sampling the location parameters.
 #' @param delta_U Numeric positive constant. Metropolis-Hastings proposal
-#' variation coefficient for sampling the latent U.
+#' variation coefficient for sampling the latent U. If `adaptive=TRUE`, `delta_U`is the starting value for the adaptation.
 #' @param Meps Numeric constant. Relative error of the jump sizes in the
 #' continuous component of the process. Smaller values imply larger number of
 #' jumps.
@@ -61,6 +61,8 @@
 #' @param printtime Logical. If TRUE, prints out the execution time.
 #' @param extras Logical. If TRUE, gives additional objects: means, sigmas,
 #' weights and Js.
+#' @param adaptive Logical. If TRUE, uses an adaptive MCMC strategy to sample the latent U (adaptive delta_U).
+#'
 #' @return The function returns a list with the following components:
 #' \item{xx}{Numeric vector. Evaluation grid.}
 #' \item{qx}{Numeric array. Matrix
@@ -88,6 +90,8 @@
 #' if extras = TRUE.}
 #' \item{Nm}{Integer constant. Number of jumps of the
 #' continuous component of the unnormalized process.}
+#' \item{delta_Us}{List of
+#' \code{length(Nit*(1-Pbi))} with the sequence of adapted delta_U used in the MH step for the latent variable U.}
 #' \item{Nx}{Integer
 #' constant. Number of grid points for the evaluation of the density estimate.}
 #' \item{Nit}{Integer constant. Number of MCMC iterations.}
@@ -102,20 +106,19 @@
 #' @author Barrios, E., Kon Kam King, G. and Nieto-Barajas, L.E.
 #' @seealso \code{\link{MixNRMI2}}, \code{\link{MixNRMI1cens}},
 #' \code{\link{MixNRMI2cens}}, \code{\link{multMixNRMI1}}
-#' @references 1.- Barrios, E., Lijoi, A., Nieto-Barajas, L. E. and Prüenster,
+#' @references 1.- Barrios, E., Lijoi, A., Nieto-Barajas, L. E. and Prünster,
 #' I. (2013). Modeling with Normalized Random Measure Mixture Models.
 #' Statistical Science. Vol. 28, No. 3, 313-334.
 #'
-#' 2.- James, L.F., Lijoi, A. and Prüenster, I. (2009). Posterior analysis for
+#' 2.- James, L.F., Lijoi, A. and Prünster, I. (2009). Posterior analysis for
 #' normalized random measure with independent increments. Scand. J. Statist 36,
 #' 76-97.
 #'
-#' 3.- Kon Kam King, G., Arbel, J. and Prüenster, I. (2016). Species
+#' 3.- Kon Kam King, G., Arbel, J. and Prünster, I. (2016). Species
 #' Sensitivity Distribution revisited: a Bayesian nonparametric approach. In
 #' preparation.
 #' @keywords distribution models nonparametrics
 #' @examples
-#'
 #' \dontrun{
 #' ### Example 1
 #' # Data
@@ -152,7 +155,7 @@ MixNRMI2cens <-
            Kappa = 0, Gama = 0.4, distr.k = "normal", distr.py0 = "normal", distr.pz0 = "gamma",
            mu.pz0 = 3, sigma.pz0 = sqrt(10), delta_S = 4, kappa = 2, delta_U = 2,
            Meps = 0.01, Nx = 150, Nit = 1500, Pbi = 0.1, epsilon = NULL,
-           printtime = TRUE, extras = TRUE) {
+           printtime = TRUE, extras = TRUE, adaptive = FALSE) {
     if (is.null(distr.k)) {
       stop("Argument distr.k is NULL. Should be provided. See help for details.")
     }
@@ -189,11 +192,17 @@ MixNRMI2cens <-
     U <- seq(Nit)
     Nmt <- seq(Nit)
     Allocs <- vector(mode = "list", length = Nit)
+    if (adaptive) {
+      optimal_delta <- rep(NA, n)
+    }
     if (extras) {
       means <- vector(mode = "list", length = Nit)
       sigmas <- vector(mode = "list", length = Nit)
       weights <- vector(mode = "list", length = Nit)
       Js <- vector(mode = "list", length = Nit)
+      if (adaptive) {
+        delta_Us <- seq(Nit)
+      }
     }
     mu.py0 <- mean(xpoint)
     sigma.py0 <- sd(xpoint)
@@ -209,13 +218,20 @@ MixNRMI2cens <-
       idx <- tt$idx
       Allocs[[max(1, j - 1)]] <- idx
       if (Gama != 0) {
-        u <- gs3(u,
-          n = n, r = rstar, alpha = Alpha, beta = Kappa,
-          gama = Gama, delta = delta_U
-        )
+        if (adaptive) {
+          tmp <- gs3_adaptive3(u, n = n, r = rstar, alpha = Alpha, kappa = Kappa, gama = Gama, delta = delta_U, U = U, iter = j, adapt = adaptive)
+          u <- tmp$u_prime
+          delta_U <- tmp$delta
+        }
+        else {
+          u <- gs3(u,
+            n = n, r = rstar, alpha = Alpha, kappa = Kappa,
+            gama = Gama, delta = delta_U
+          )
+        }
       }
       JiC <- MvInv(
-        eps = Meps, u = u, alpha = Alpha, beta = Kappa,
+        eps = Meps, u = u, alpha = Alpha, kappa = Kappa,
         gama = Gama, N = 50001
       )
       Nm <- length(JiC)
@@ -264,6 +280,9 @@ MixNRMI2cens <-
         sigmas[[j]] <- Tauz
         weights[[j]] <- J / sum(J)
         Js[[j]] <- J
+        if (adaptive) {
+          delta_Us[j] <- delta_U
+        }
       }
     }
     tt <- comp2(y, z)
@@ -281,6 +300,9 @@ MixNRMI2cens <-
       sigmas <- sigmas[-biseq]
       weights <- weights[-biseq]
       Js <- Js[-biseq]
+      if (adaptive) {
+        delta_Us <- delta_Us[-biseq]
+      }
     }
     cpo <- 1 / apply(1 / fx[, -biseq], 1, mean)
     if (printtime) {
@@ -298,6 +320,9 @@ MixNRMI2cens <-
       res$sigmas <- sigmas
       res$weights <- weights
       res$Js <- Js
+      if (adaptive) {
+        res$delta_Us <- delta_Us
+      }
     }
     return(structure(res, class = "NRMI2"))
   }
