@@ -75,5 +75,5 @@ Convert_to_matrix_list <- function(fitlist, thinning_to = 1000, parallel = TRUE,
 #' @param ncores Specify the number of cores to use in the conversion
 #' @return a coda::mcmc object
 convert_to_mcmc <- function(fitlist, thinning_to = 1000, ncores = parallel::detectCores()) {
-  coda::as.mcmc(lapply(Convert_to_matrix_list(fitlist, thinning_to = thinning_to, ncores = ncores), coda::mcmc))
+  coda::as.mcmc.list(coda::as.mcmc(lapply(Convert_to_matrix_list(fitlist, thinning_to = thinning_to, ncores = ncores), coda::mcmc)))
 }
